#!/bin/bash
#
# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2018. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *****************************************************************
#

if [ "${LIB_HARDWARE_CHECKS_SOURCED}" = "" ] ; then
LIB_HARDWARE_CHECKS_SOURCED="true"

##############################################################################
# Use the snapml_rank_gen program to verify that all of the hosts have the same
# hardware configuration.
# Globals:
#   ${VERBOSE}
#   ${WORKING_DIR}
#   ${MPI_ARGS}
# Arguments:
#   Host List
#   Additional rankgen arguments
# Returns:
#   None
##############################################################################
getHostConfigs()
{
  local HOSTS="${1}"
  shift
  local SPLIT_HOSTS=($(echo ${HOSTS} | tr "," " "))
  local ENCOUNTERED_ERROR="false"
  for ((i=0; i<${#SPLIT_HOSTS[@]}; i++)); do
    mpirun -timeout "${DEBUG_TIMEOUT}" "${MPI_ARGS[@]}" -n 1 -H ${SPLIT_HOSTS[i]} snapml_rank_gen.py --machine_report "$@" ${HOSTS} > "${WORKING_DIR}/${SPLIT_HOSTS[i]}_config.out" 2> "${WORKING_DIR}/${SPLIT_HOSTS[i]}_config.err"
    local ret_code=$?
    if [ ${ret_code} -ne 0 ]; then
      ENCOUNTERED_ERROR="true"
      print_error "ERROR" $MSG_HOST_CFG
      [ "${VERBOSE}" = "true" ] && >&2 cat "${WORKING_DIR}/${SPLIT_HOSTS[i]}_config.err"
      continue
    fi
  done

  if [ ${ENCOUNTERED_ERROR} = "true" ]; then
    exit 1
  fi

}

##############################################################################
# Verify that the MOFED user-space packages are installed by running the ofed_info command
# on all the hosts when using Spectrum MPI and InfiniBand.
# Globals:
#   ${DEBUG_TIMEOUT}
#   ${WORKING_DIR}
#   ${MPI_ARGS}
# Arguments:
#   Host List
# Returns:
#   None
##############################################################################
verifyInfiniBandConfig()
{
  # Only check for Spectrum MPI and when -tcp and -pami_noib are not used
    if [[ "${USE_SPECTRUM}" != "true" ]] || [[ " ${MPI_ARGS[*]} " == *" -tcp "* ]] ||
       [[ " ${MPI_ARGS[*]} " == *" -pami_noib "* ]]; then
       return;
    fi
    local HOSTS="${1}"
    local SPLIT_HOSTS=($(echo ${HOSTS} | tr "," " "))
    local ENCOUNTERED_ERROR="false"
    for ((i=0; i<${#SPLIT_HOSTS[@]}; i++)); do
      local HOST="${SPLIT_HOSTS[i]}"
      local TEMP_RANK_FILE="${WORKING_DIR}/${HOST}_temp_rankfile"
      echo "rank 0=${HOST} slot=0" > ${TEMP_RANK_FILE}
      mpirun -timeout "${DEBUG_TIMEOUT}" "${MPI_ARGS[@]}" -n 1 --rankfile ${TEMP_RANK_FILE} ofed_info -n &> /dev/null
      local ret_code=$?
      if [ ${ret_code} -ne 0 ]; then
	 ENCOUNTERED_ERROR="true"
           print_error "ERROR" $MSG_INFINIBAND_NOT_SETUP
      fi
  done

  if [ ${ENCOUNTERED_ERROR} = "true" ]; then
     exit 1
     fi
 }

fi
