# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2017, 2018. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# ******************************************************************

import ctypes
import os

from ctypes.util import find_library
lib_name = find_library('mpi')
ctypes.CDLL(lib_name, mode=ctypes.RTLD_GLOBAL)

mpi_vars = { 'OMPI_COMM_WORLD_LOCAL_RANK':0 }
mpi_init_status = True

# Ensure all the necessary ENV variables are available;
# else don't initialize SnapML & restrict SnapML API invocations.
for var in mpi_vars:
    val = os.getenv(var)
    if val is None:
        mpi_init_status = False
        break;
    mpi_vars[var] = val

if mpi_init_status:
    val = os.getenv("DLI_SNAPML_MPI")
    if val:
        rank_local = mpi_vars['OMPI_COMM_WORLD_LOCAL_RANK']
        os.environ["CUDA_VISIBLE_DEVICES"] = rank_local

#Local code
from _snap_ml.LogisticRegression import LogisticRegression
from _snap_ml.LinearRegression import LinearRegression
from _snap_ml.SupportVectorMachine import SupportVectorMachine
from _snap_ml.DecisionTreeClassifier import DecisionTreeClassifier
from _snap_ml.RandomForestClassifier import RandomForestClassifier

if mpi_init_status:
    #This is only specific to mpi and n/a for local
    from _snap_ml.utils import read_from_snap_format, dump_to_snap_format
else:
    #This is only specific to local
    from _snap_ml.utils import get_gpu_count
    from _snap_ml import io

