# News20 example

We will train a Logistic Regression model,Linear Regression Model and Support vector machine Model on the news20 dataset, using both scikit-learn (sklearn) and pai4sk. Note that scikit-learn does not provide an MPI implementation. We will however still perform this comparison in order to mainly verify the accuracy metrics.

The news20 dataset is avaliable in the LIBSVM repository.

The problem is described as follows:

    This is a classification problem to classify news articles to positive and negative.

This dataset is a binary text classification dataset. It is a size-balanced two-class variant of the UCI - Twenty Newsgroups dataset (Blake and Merz, 1998). The positive class consists of the 10 groups with names of formsci., comp., or misc.forsale, and the negative class consists of the other 10 groups. The dataset consists of 20K training examples and 1.3M features.

## Download the news20 dataset for examples:

```
mkdir data
cd data
wget https://www.csie.ntu.edu.tw/~cjlin/libsvmtools/datasets/binary/news20.binary.bz2
bunzip2 news20.binary.bz2
cd ..
```
## Pre-processing Data

First we split the data into train and test datasets.
Next we write the train/test data to disk as binary scipy/numpy files. This helps to achieve fast data loading.
This format will be used for loading the datasets using `sklearn`. `Sklearn` will be used for performance comparison.
Finally we write the train and test datasets in distributed snap format which will be used only for training the `pai4sk` SupportVectorMachine model.
This format helps achieve higher performance.

The entire pre-processing code can be run by executing `snaprun python $CONDA_PREFIX/pai4sk/mpi-examples/example-news20/preprocess-news20.py`

## Load pre-processed data

After running the data pre-processing steps above, we are ready to perform our benchmarking: `snap.ml` vs. `sklearn`.
Pre-processed data can be loaded with below methods. See API documentation of the following methods for more details.
```
1.`load_from_snap_format`
See example-svm-snap-format.py
2.`load_snap_file`
See example-svm-snap-file.py
3.`load_from_svmlight_format`
See example-svm.py
4.`load_svmlight_file`
See example-svm-svmlight-file.py
```

`load_from_snap_format` and `load_from_svmlight_format` return data_ptr.  data_ptr will be of type DensePartition, SparsePartition or ConstantValueSparsePartition.

`load_snap_file` returns dense or sparse matrices as X,y. Here X will be npy, csr or csc and y will be npy.

`load_svmlight_file` returns sparse matrix X and numpy array y. Here X will be csr or csc.

Note: dense snap data can be loaded with `load_from_snap_format` and `load_snap_file` methods.

## Run examples

Commands to run example-svm.py are shown below. Other examples also take same command line arguments.

snaprun python $CONDA_PREFIX/pai4sk/mpi-examples/example-news20/example-svm.py --data_path path/to/data

The example above runs on CPU.

Note: By default the location of `--data_path` is current directory. Parent directory of the directory 'data/' is to be given as parameter to --data_path option.

Command to run 2 MPI processes on 2 nodes:

snaprun -H host1,host2 python $CONDA_PREFIX/pai4sk/mpi-examples/example-news20/example-svm.py

&copy; Copyright IBM Corporation 2018, 2019
