# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2019. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *****************************************************************

from __future__ import print_function

import time

# pai4sk explicit imports for snap_ml APIs
from pai4sk import MPI
from pai4sk.sml_io import load_from_snap_format
from pai4sk import SupportVectorMachine
from pai4sk.sml_metrics import mean_squared_error, accuracy_score

# pai4sk explicit imports for sklearn APIs
from pai4sk.datasets import load_svmlight_fileSklearn
from pai4sk.svm import LinearSVCSklearn as LinearSVC
from pai4sk.metrics import accuracy_scoreSklearn,mean_squared_errorSklearn

(comm_size, rank) = MPI.Comm_get_info()

import argparse

defaultPath = "."
CLI=argparse.ArgumentParser()
CLI.add_argument(
   "--data_path",
   type=str,
   default=defaultPath
)
CLI.add_argument(
   "--device_ids",
   nargs="*",
   type=int,
   default=[]
)
CLI.add_argument(
    "--use_gpu",
    action = 'store_true',
    default=False
)
CLI.add_argument(
    "--skip_sklearn",
    action = 'store_true',
    default=False
)
CLI.add_argument(
    "--use_balanced_class_weights",
    action = 'store_true',
    default=False
)

args = CLI.parse_args()

if args.use_balanced_class_weights:
  class_weight = "balanced"
else:
  class_weight = None

data = load_from_snap_format("data/news20.train.snap")

# Create a Support Vector Machine (setting GPU appropriately)
svm = SupportVectorMachine(device_ids=args.device_ids, use_gpu=args.use_gpu,class_weight=class_weight)

# Training
t0 = time.time()
svm.fit(data)

print("[pai4sk] MPI process %d : Training time (s):  %.2f" % (rank, time.time()-t0))

# Inference
pred_class = svm.predict(data)

# Evaluate log-loss on test set
print("[pai4sk] MPI process %d : Accuracy:                 %.4f" % (rank, accuracy_score(data, pred_class)))
print("[pai4sk] MPI process %d : Mean squared error:       %.4f" % (rank, mean_squared_error(data, pred_class)))

if args.skip_sklearn:
    print('Execution using scikit-learn is skipped.')
    exit()

X,y = load_svmlight_fileSklearn(args.data_path + "/data/news20.binary")

# Create a LogisticRegression (dual is faster for this application)
clf = LinearSVC(dual=True, fit_intercept=False, loss="hinge")

# Training time
t0 = time.time()
clf.fit(X, y)

if (rank == 0):
    print("[sklearn] Training time (s):  %.2f" % (time.time()-t0))

# Inference
pred_class = clf.predict(X)

if (rank == 0):
    print("[sklearn] Accuracy:              %.4f" % (accuracy_scoreSklearn(y, pred_class)))
    print("[sklearn] Mean squared error:    %.4f" % (mean_squared_errorSklearn(y, pred_class)))
