# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2019. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *****************************************************************

from __future__ import print_function
import argparse
import os

from sklearn.datasets import load_svmlight_file
from sklearn.model_selection import train_test_split
import scipy as sp

import numpy as np
from snap_ml_mpi.Utils import dump_to_snap_format

defaultPath = os.getcwd()
CLI=argparse.ArgumentParser()
CLI.add_argument(
   "--data_path",
   type=str,
   default=defaultPath
)

args = CLI.parse_args()

# Load the data
print("Loading news20 dataset...")
filename = args.data_path + "/data/news20.binary"
X, y = load_svmlight_file(filename)

print('Splitting data...')
# Make the train-test split
X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.25, random_state=42)

print('Saving data in sklearn format...')
# Save train and test datasets for fast sklearn data loading
sp.sparse.save_npz(args.data_path + "/data/news20.X_train", X_train, compressed=False)
sp.sparse.save_npz(args.data_path + "/data/news20.X_test",  X_test,  compressed=False)

# Save train and test datasets for fast sklearn data loading
np.save(args.data_path + "/data/news20.y_train", y_train)
np.save(args.data_path + "/data/news20.y_test", y_test)


print('Saving data in distributed snap.ml format...')
dump_to_snap_format(X_train, y_train, args.data_path + "/data/news20.train.snap")
dump_to_snap_format(X_test, y_test, args.data_path + "/data/news20.test.snap")
