from __future__ import print_function
import time
import sys
import argparse
from pai4sk.metrics.pairwise import word_movers_distance
from pai4sk.simsearch.loaders import load_20News
from pai4sk.simsearch.embeddings import load_embedding_vectors
from pai4sk.simsearch.evaluate import evaluate_topk

defaultPath = "."

CLI=argparse.ArgumentParser()
CLI.add_argument(
    "--data_path",
    type=str,
    default=defaultPath
)
CLI.add_argument(
   "--use_gpu",
   action = 'store_true',
   default=False
)
CLI.add_argument(
   "--top_k",
   type=int,
   default=32
)

args = CLI.parse_args()


# LOAD EMBEDDINGS
W = load_embedding_vectors('vectors.npy')

# LOAD DATA FILES
X, labels, ids = load_20News(args.data_path + "/data/20news-18828/", 'vocabulary.txt')


# RUN WMD on CPU/GPU
if (args.use_gpu==True):
    print("Running the GPU library")
else:
    print("Running the CPU library")
start = time.time()
D = word_movers_distance(W, X, use_gpu=args.use_gpu)
end = time.time()
print("Took " + str(end-start) + " seconds")



# EVALUATE TOP-K(for example TOP-32) SEARCH ACCURACY
# Evaluates search accuracy for News20 documents for the top K samples (K in powers of 2 from 1 to K)
# `labels` to be passed as argument only once if WMD is computed among the documents in a text dataset. It should be passed twice if WMD is computed among documents in two different datasets

k_vec, prec_vec, topk_indices, topk_values = evaluate_topk(D, args.top_k, labels)
print("\nTop-K precision results")
print("K:\t\t" + str(k_vec))
print("Precision:\t" + str(prec_vec))
